spindry
=======


Molecules
---------


.. toctree::
  :maxdepth: 1

  Atom <_autosummary/spindry.Atom>
  Bond <_autosummary/spindry.Bond>
  Molecule <_autosummary/spindry.Molecule>
  SupraMolecule <_autosummary/spindry.SupraMolecule>



Potentials
----------

.. toctree::
  :maxdepth: 1

  Potential <_autosummary/spindry.Potential>
  SpdPotential <_autosummary/spindry.SpdPotential>
  VaryingEpsilonPotential <_autosummary/spindry.VaryingEpsilonPotential>

Optimisers
----------

.. toctree::
  :maxdepth: 1

  Spinner <_autosummary/spindry.Spinner>


Utilities
---------

.. toctree::
  :maxdepth: 1

   get_atom_distance <_autosummary/spindry.get_atom_distance>
   calculate_centroid_distance <_autosummary/spindry.calculate_centroid_distance>
   calculate_min_atom_distance <_autosummary/spindry.calculate_min_atom_distance>